@@ -1,7 +1,6 @@
 import time
 import os
 from datetime import datetime
-from ..CommonDefine import LogLevel
 
 # DIS
 # from .CommonDefine import LogLevel
@@ -55,7 +54,7 @@ if __name__ == '__main__':
     # Logger.get_logger().warning("This is a test warning.")
     # Logger.get_logger().error("This is a test error.")
     Logger.get_logger().debug("This is a test fatal.")
-    Logger.get_logger().warn("This is a test fatal.")
-    Logger.get_logger().error("This is a test fatal.")
-    # Logger.get_logger().info("This is a test info.")
-    # Logger.get_logger().log_debug("This is a test debug.")
\ No newline at end of file
+    Logger.get_logger().warn("This is a test warn.")
+    Logger.get_logger().error("This is a test error.")
+    Logger.get_logger().info("This is a test info.")
+    Logger.get_logger().log_debug("This is a test debug.")
\ No newline at end of file
